numpy.polynomial.Chebyshev
==========================

.. currentmodule:: numpy.polynomial

.. autoclass:: Chebyshev

   

   .. HACK
      .. autosummary::
         :toctree:
      
         Chebyshev.__init__
         Chebyshev.convert
         Chebyshev.copy
         Chebyshev.cutdeg
         Chebyshev.degree
         Chebyshev.deriv
         Chebyshev.has_samecoef
         Chebyshev.has_samedomain
         Chebyshev.has_samewindow
         Chebyshev.integ
         Chebyshev.linspace
         Chebyshev.mapparms
         Chebyshev.roots
         Chebyshev.trim
         Chebyshev.truncate



   

